'
'  This is an example so remember to change every fake string data such as:
'  "mail.host.com", "password",	"alice@mail.com" to real-word values.
'  
'  For additional info and faq visit: http://www.lesnikowski.com/mail
'  
'

Imports System.IO
Imports Lesnikowski.Mail                            ' Email parser
Imports Lesnikowski.Client                          ' POP3 and SMTP clients

Class Example1

    Shared Sub Receive()

        Dim pop3 As New Pop3
        pop3.User = "lesnikowski"                   ' Set user name and password
        pop3.Password = "password"

        Try
            pop3.Connect("mail.host.com")           ' Connect to server and login

            If (pop3.HasTimeStamp = True) Then      ' Try APOP secure login
                pop3.APOPLogin()
            Else
                pop3.Login()
            End If

            pop3.GetAccountStat()                   ' Get account statistics

            For i As Integer = 1 To pop3.MessageCount
                Try
                    ' Receive email
                    ' Use MailMessage class to get real mail structure or 
                    ' SimpleMailMessage to get simple interface.

                    Dim simpleMail As SimpleMailMessage
                    simpleMail = SimpleMailMessage.Parse(pop3.GetMessage(i))

                    Console.WriteLine("-- email {0} --", i)

                    ' Write out email's subject
                    Console.WriteLine(simpleMail.Subject)

                    ' Write out email's from.
                    Dim mb As MailBox
                    For Each mb In simpleMail.From

                        Console.Write("From: ")
                        ' Write out name, if it was provided
                        If (mb.Name <> Nothing) Then
                            Console.Write(mb.Name)
                        End If
                        ' Write out address
                        Console.WriteLine("<{0}>", mb.Address)
                    Next mb

                    ' Write out email's body.
                    If (simpleMail.HtmlData Is Nothing) Then
                        Console.WriteLine(simpleMail.HtmlDataString)   ' HTML email
                    Else
                        Console.WriteLine(simpleMail.TextDataString)   ' Text email
                    End If

                    ' Write out Attachments
                    Dim attachment As MimeData
                    For Each attachment In simpleMail.Attachments
                        Console.WriteLine(attachment.FileName)
                        ' Save attachment to disk
                        attachment.Save("c:\" + attachment.FileName)
                    Next attachment

                    ' pop3.DeleteMessage(i)		    ' Delete message from POP3 server

                Catch ex As MailException
                    Console.WriteLine(ex.Message)   ' Invalid email format
                End Try
            Next

        Catch ex As ServerException
            Console.WriteLine(ex.Message)           ' Server error
        Finally
            pop3.Close(False)                       ' Close connection
        End Try

    End Sub

    Shared Sub Send()
        ' Create new email message
        Dim sm As SimpleMailMessage = New SimpleMailMessage

        sm.From.Add(New MailBox("alice@mail.com", "Alice"))
        sm.To.Add(New MailBox("bob@mail.com", "Bob"))
        sm.Subject = "Test"
        sm.TextDataString = "This is plain text message."
        sm.HtmlDataString = _
            "This is <strong>HTML</strong> message, " _
            & "with embeded image:<br />" _
            & "<img src = 'cid:image1' />."

        ' Read image from disk...
        Dim image As MimeData = New MimeData
        image.ContentType = New ContentType(MimeType.Image, MimeSubtype.Jpeg)
        image.ContentId = "image1"
        image.LoadFromFile("../../../image.jpg")

        ' ...and add it to Visuals collection
        sm.Visuals.Add(image)

        ' Write email to disk, just to see how it looks.
        Dim str As String = sm.CreateMail().CreateString()
        Dim fileName As String = "c:\mail.eml"
        Dim sw As StreamWriter = File.CreateText(fileName)
        sw.Write(str)
        sw.Close()
        Console.WriteLine("Email saved in {0}.", fileName)

        ' Send it
        Dim smtp As Smtp = New Smtp
        smtp.User = "lesnikowski"                       ' Set user name and password
        smtp.Password = "password"

        Try
            smtp.Connect("mail.host.com")               ' Connect to server and login
            smtp.Ehlo(HeloType.EhloHelo, "yourname")    ' Say hello to the server
            smtp.Login()
            Dim smtpMail As SmtpMail = New SmtpMail(sm.CreateMail())
            smtp.SendMessage(smtpMail)                  ' Send email message

        Catch ex As ServerException
            Console.WriteLine(ex.Message)               'Server error
        Finally
            smtp.Close(False)                           'Close connection
        End Try

    End Sub

    Shared Sub Main()
        Console.WriteLine("Receiving...")
        Receive()
        Console.WriteLine("Receiving completed." + vbCrLf + "Press enter...")
        Console.ReadLine()

        Console.WriteLine("Sending...")
        Send()
        Console.WriteLine("Sending completed." + vbCrLf + "Press enter...")
        Console.ReadLine()
    End Sub


End Class